@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,7 +18,7 @@ package Kernel::Modules::AgentZoom;
 use strict;
 use warnings;
 
-use Kernel::System::CustomerUser;
+our $ObjectManagerDisabled = 1;
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -27,30 +27,25 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    # check needed objects
-    for (qw(ParamObject DBObject LayoutObject LogObject ConfigObject )) {
-        if ( !$Self->{$_} ) {
-            $Self->{LayoutObject}->FatalError( Message => "Got no $_!" );
-        }
-    }
-
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
     # compat link
     my $Redirect = $ENV{REQUEST_URI};
     if ($Redirect) {
         $Redirect =~ s/AgentZoom/AgentTicketZoom/;
     }
     else {
-        $Redirect = $Self->{LayoutObject}->{Baselink}
+        $Redirect = $LayoutObject->{Baselink}
             . 'Action=AgentTicketZoom;TicketID='
             . $Self->{TicketID};
     }
-    return $Self->{LayoutObject}->Redirect( OP => $Redirect );
+    return $LayoutObject->Redirect( OP => $Redirect );
 }
 
 1;
