@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::CustomerCompany;
@@ -306,6 +306,7 @@ get list of customer companies.
 
     my %List = $CustomerCompanyObject->CustomerCompanyList(
         Valid => 0,
+        Limit => 0,     # optional, override configured search result limit (0 means unlimited)
     );
 
     my %List = $CustomerCompanyObject->CustomerCompanyList(
@@ -315,8 +316,8 @@ get list of customer companies.
 Returns:
 
 %List = {
-          'example.com' => 'example.com Customer Inc.        ',
-          'acme.com'    => 'acme.com Acme, Inc.        '
+          'example.com' => 'example.com Customer Inc.',
+          'acme.com'    => 'acme.com Acme, Inc.'
         };
 
 =cut
@@ -352,10 +353,10 @@ sub DESTROY {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
