@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::SupportDataCollector::Plugin::Database::mysql::Charset;
@@ -13,12 +13,14 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+use Kernel::Language qw(Translatable);
+
 our @ObjectDependencies = (
     'Kernel::System::DB',
 );
 
 sub GetDisplayPath {
-    return 'Database';
+    return Translatable('Database');
 }
 
 sub Run {
@@ -36,16 +38,16 @@ sub Run {
         if ( $Row[1] =~ /utf8/i ) {
             $Self->AddResultOk(
                 Identifier => 'ClientEncoding',
-                Label      => 'Client Connection Charset',
+                Label      => Translatable('Client Connection Charset'),
                 Value      => $Row[1],
             );
         }
         else {
             $Self->AddResultProblem(
                 Identifier => 'ClientEncoding',
-                Label      => 'Client Connection Charset',
+                Label      => Translatable('Client Connection Charset'),
                 Value      => $Row[1],
-                Message    => 'Setting character_set_client needs to be utf8.',
+                Message    => Translatable('Setting character_set_client needs to be utf8.'),
             );
         }
     }
@@ -55,24 +57,22 @@ sub Run {
         if ( $Row[1] =~ /utf8/i ) {
             $Self->AddResultOk(
                 Identifier => 'ServerEncoding',
-                Label      => 'Server Database Charset',
+                Label      => Translatable('Server Database Charset'),
                 Value      => $Row[1],
             );
         }
         else {
             $Self->AddResultProblem(
                 Identifier => 'ServerEncoding',
-                Label      => 'Server Database Charset',
+                Label      => Translatable('Server Database Charset'),
                 Value      => $Row[1],
-                Message    => 'Setting character_set_database needs to be UNICODE or UTF8.',
+                Message    => Translatable('Setting character_set_database needs to be UNICODE or UTF8.'),
             );
         }
     }
 
     my @TablesWithInvalidCharset;
-
-    # Views have engine == null, ignore those.
-    $DBObject->Prepare( SQL => 'show table status where engine is not null' );
+    $DBObject->Prepare( SQL => 'show table status' );
     while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( $Row[14] !~ /^utf8/i ) {
             push @TablesWithInvalidCharset, $Row[0];
@@ -81,15 +81,15 @@ sub Run {
     if (@TablesWithInvalidCharset) {
         $Self->AddResultProblem(
             Identifier => 'TableEncoding',
-            Label      => 'Table Charset',
+            Label      => Translatable('Table Charset'),
             Value      => join( ', ', @TablesWithInvalidCharset ),
-            Message    => 'There were tables found which do not have utf8 as charset.',
+            Message    => Translatable('There were tables found which do not have utf8 as charset.'),
         );
     }
     else {
         $Self->AddResultOk(
             Identifier => 'TableEncoding',
-            Label      => 'Table Charset',
+            Label      => Translatable('Table Charset'),
             Value      => '',
         );
     }
@@ -101,11 +101,11 @@ sub Run {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
 
